Slot: pv_formula - LinkML Model

# Slot: pv_formula

Defines the specific formula to be used to generate the permissible values.

URI: linkml:pv_formula

## Domain and Range

EnumDefinition → 0..1 pv_formula_options

## Parents

## Children

## Used by

- EnumDefinition

## Other properties

Comments: |  | you cannot have BOTH the permissible_values and permissible_value_formula tag
|  | code_set must be supplied for this to be valid